==> zircon-1.17p4b37.tar.gz: zircon-1.17p4b37/lang/english.tcl <==
#
# $Source:$
# $Date:$
# $Revision:$
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
array set ztrans {
    abort	Abort
    accept	Accept
    action	Action
    actions	Actions
    anonymous	Anonymous
    append	Append
    away	Away
    back	Back
    ban		Ban
    brb		BRB
    busy	Busy
    buttons	Buttons  
    call	Call
    cancel	Cancel
    channel	Channel
    channels	Channels
    chanop	ChanOp
    chat	Chat
    clear	Clear
    close	Close
    configure	Configure
    connect	Connect
    crypt	Crypt
    ctcp	CTCP
    dcc		DCC
    debug	Debug
    default	Default
    delete	Delete
    dismiss	Dismiss
    draw	Draw
    dump	Dump
    empty	Empty
    error	Error
    exec	Exec
    favourites	Favourites
    filename    Filename
    filter	Filter
    finger	Finger
    flush	Flush
    get		Get
    help	Help
    history	History
    hostname	Hostname
    info	Info
    invisible	Invisible
    invite	Invite
    irc		IRC
    ircname	Ircname
    join	Join
    jump	Jump
    keep	Keep
    key		Key
    kick	Kick
    kill	Kill
    leave	Leave
    log		Log
    limit	Limit
    list	List
    map		Map
    message	Message
    messages	Messages
    mode	Mode
    moderated	Moderated
    monitor	Monitor
    name	Name
    names	Names
    new		New
    nickname	Nickname
    nocase	Nocase
    notice	Notice
    notify	Notify
    offer	Offer
    ok		OK
    open	Open
    operator	Operator
    parameter	Parameter
    parameters	Parameters
    password	Password
    pattern	Pattern
    people	People
    plugin	{Plug In}
    port	Port
    private	Private
    quiet	Quiet
    quit	Quit
    reconnecting	Reconnecting
    refresh	Refresh
    register	Register
    reject	Reject
    save	Save
    script	Script
    scroll	Scroll
    secret	Secret
    send	Send
    server	Server
    servers	Servers
    service	Service
    services	Services
    set		Set
    shutdown	Shutdown
    signoff	Signoff
    silence	Silence
    sound	Sound
    speak	Speak
    text	Text
    time	Time
    topic	Topic
    unban	Unban
    user	User
    users	Users
    view	View
    who		Who
    whois	Whois
    whowas	Whowas
    windows	Windows
}
#
# Compounds of the above that are no language dependent
#
array set ztrans "
    bankick	{$ztrans(ban)+$ztrans(kick)}
"

==> zircon-1.18.30.tar.gz: zircon-1.18.30/lang/english.tcl <==
#
# $Source: /home/nlfm/Working/Zircon/Released/lang/RCS/english.tcl,v $
# $Date: 1996/12/12 14:07:39 $
# $Revision: 1.18.1.1 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
array set ztrans {
    abort	Abort
    accept	Accept
    action	Action
    actions	Actions
    anonymous	Anonymous
    append	Append
    away	Away
    back	Back
    ban		Ban
    brb		BRB
    busy	Busy
    buttons	Buttons  
    call	Call
    cancel	Cancel
    channel	Channel
    channels	Channels
    chanop	ChanOp
    chat	Chat
    clear	Clear
    clone	Clone
    close	Close
    configure	Configure
    connect	Connect
    crypt	Crypt
    ctcp	CTCP
    dcc		DCC
    debug	Debug
    default	Default
    delete	Delete
    dismiss	Dismiss
    draw	Draw
    dump	Dump
    edit	Edit
    empty	Empty
    error	Error
    exec	Exec
    favourites	Favourites
    filename    Filename
    filter	Filter
    finger	Finger
    flags	Flags
    flush	Flush
    get		Get
    help	Help
    history	History
    hostname	Hostname
    info	Info
    invisible	Invisible
    invite	Invite
    irc		IRC
    ircname	Ircname
    join	Join
    jump	Jump
    keep	Keep
    key		Key
    kick	Kick
    kill	Kill
    leave	Leave
    limit	Limit
    list	List
    load	Load
    local	Local
    log		Log
    map		Map
    message	Message
    messages	Messages
    mode	Mode
    moderated	Moderated
    monitor	Monitor
    name	Name
    names	Names
    new		New
    nickname	Nickname
    nocase	Nocase
    notice	Notice
    notify	Notify
    offer	Offer
    ok		OK
    open	Open
    operator	Operator
    other	Other
    parameter	Parameter
    parameters	Parameters
    password	Password
    pattern	Pattern
    people	People
    plugin	{Plug In}
    port	Port
    private	Private
    public	Public
    query	Query
    quiet	Quiet
    quit	Quit
    reconnecting	Reconnecting
    refresh	Refresh
    register	Register
    reject	Reject
    rejoin	Rejoin
    save	Save
    script	Script
    scroll	Scroll
    secret	Secret
    send	Send
    server	Server
    servers	Servers
    service	Service
    services	Services
    set		Set
    shutdown	Shutdown
    signoff	Signoff
    silence	Silence
    sorted	Sorted
    sound	Sound
    speak	Speak
    text	Text
    time	Time
    type	Type
    topic	Topic
    unban	Unban
    unload	Unload
    user	User
    users	Users
    view	View
    who		Who
    whois	Whois
    whowas	Whowas
    windows	Windows
}
#
# Compounds of the above that are no language dependent
#
array set ztrans "
    bankick	{$ztrans(ban)+$ztrans(kick)}
"
